// ignore_for_file: slash_for_doc_comments

part of 'onyx.dart';

/**
 * ONYX Configuration options for the OnyxConfigurationBuilder
 */
class OnyxOptions {
  /**
   * Specify the ONYX license key.
   * @param licenseKey (required) the Onyx license key
   */
  String? licenseKey = "";

  /**
   * Specify whether or not to return the raw image.
   * Returned in the OnyxResult
   */
  bool returnRawImage = false;

  /**
   * Specify whether or not to return the processed image.  This would be the most
   * common image type to use for conversion to WSQ or for matching.
   * Returned in the OnyxResult
   */
  bool returnProcessedImage = true;

  /**
   * Specify whether or not to return the enhanced image.  This is a special image that
   * works better with certain matching algorithms, but needs special testing to make sure it
   * will match.
   * Returned in the OnyxResult
   */
  bool returnEnhancedImage = false;

  /**
   * Specify whether or not to return a slap image. This contains all fingers captured
   * within a single image as specified in the FBI EBTS format.
   * Returned in the {@link OnyxResult}
   */
  bool returnSlapImage = false;

  /**
   * Specify whether or not to return the binarized processed fingerprint image
   * in the OnyxResult
   */
  bool shouldBinarizeProcessedImage = false;

  /**
   * Specify whether to return a FullFrame image.  This returns
   * an image that is suitable for finger detection in a full frame.
   * Returned in the OnyxResult
   */
  bool returnFullFrameImage = false;

  /**
   * Specify the maximum height for the FullFrame image to be returned, so for example,
   * if you want a 1920 height image returned, pass in 1920.0f for the value.  It will a full frame
   * image resized to 1920 for the maximum height.  To get the original height of the full frame, to
   * get full resolution, pass in a value of 1.0f.
   */
  double fullFrameMaxImageHeight = 1920.0;

  /**
   * Specify whether or not to return the WSQ image.  This will tell the SDK to return
   * a WSQ image suitable for use in matching and other applications.
   */
  bool returnWSQ = false;

  /**
   * Specify whether or not the capture task will return the specified
   * com.dft.onyxcamera.config.OnyxConfiguration.FingerprintTemplateType
   * in the OnyxResult
   * The ISO template is the ISO/IEC 19794-4 standard minutiae based template
   * The INNOVATRICS template is a proprietary fingerprint template that is highly scale tolerant and
   * useful for touchless matching
   */
  FingerprintTemplateType returnFingerprintTemplate = FingerprintTemplateType.NONE;

  /**
   * Specify the crop width for the capture image.  This will determine the image dimensions
   * in length and width for the resulting images.  This should be set to whatever is required
   * for the matching algorithm that is going to be used.
   */
  double cropSizeWidth = 300;

  /**
   * Specify the crop height for the capture image.  This will determine the image dimensions
   * in length and width for the resulting images.  This should be set to whatever is required
   * for the matching algorithm that is going to be used.
   */
  double cropSizeHeight = 512;

  /**
   * Specify the crop factor for the capture image.  This has a built in scaling factor and
   * this crop factor should be adjusted until you get an image that looks close to images that are
   * known to match against whatever biometric system you are attempting to match against.
   */
  double cropFactor = 1.0;

  /**
   * Specify that the spinner should be shown during OnyxConfiguration and during
   * image processing.
   */
  bool showLoadingSpinner = false;

  /**
   * Specify the method of capture to be a manual capture of the fingerprint.
   */
  bool useManualCapture = false;

  /**
   * Specify the manual capture text that is displayed on screen.
   */
  String manualCaptureText = "";

  /**
   * Specify to use ONYX LIVE_FINGER liveness detection as part of the configuration.
   * This will take additional processing time.
   */
  bool useOnyxLive = false;

  /**
   * Specify to use the flash
   */
  bool useFlash = true;

  /**
   * Specify the orientation of the reticle Reticle.Orientation
   */
  ReticleOrientation reticleOrientation = ReticleOrientation.LEFT;

  /**
   * Specify to compute NFIQ metrics
   */
  bool computeNfiqMetrics = false;

  /**
   * Specify target pixels per inch
   */
  double targetPixelsPerInch = -1.0;

  /**
   * Specify the subject id
   */
  String? subjectId;

  /**
   * For future use.  Not currently implemented.  Specify whether to upload capture metrics result.
   * This will be used to improve ONYX capture and quality performance in the future.
   */
  bool uploadMetrics = true;

  /**
   * Specify to return OnyxError on low quality imagery
   */
  bool returnOnyxErrorOnLowQuality = false;

  /**
   * Specify a double value between 0.0 - 1.0 to set the threshold for QualityNet to capture.  Higher
   * values mean higher image quality.
   */
  double captureQualityThreshold = 0.8;

  ///returns the options as a serialized list.
  dynamic toParams() {
    return <String, dynamic>{
      "licenseKey": licenseKey,
      "returnRawImage": returnRawImage.toString(),
      "returnProcessedImage": returnProcessedImage.toString(),
      "returnEnhancedImage": returnEnhancedImage.toString(),
      "returnSlapImage": returnSlapImage.toString(),
      "shouldBinarizeProcessedImage": shouldBinarizeProcessedImage.toString(),
      "returnFullFrameImage": returnFullFrameImage.toString(),
      "fullFrameMaxImageHeight": (fullFrameMaxImageHeight).toString(),
      "returnWSQ": returnWSQ.toString(),
      "returnFingerprintTemplate":
          returnFingerprintTemplate.toString(),
      "cropSizeWidth": cropSizeWidth.toString(),
      "cropSizeHeight": cropSizeHeight.toString(),
      "cropFactor": cropFactor.toString(),
      "showLoadingSpinner": showLoadingSpinner.toString(),
      "useManualCapture": useManualCapture.toString(),
      "manualCaptureText": manualCaptureText.toString(),
      "useOnyxLive": useOnyxLive.toString(),
      "useFlash": useFlash.toString(),
      "reticleOrientation": reticleOrientation.toValueString(),
      "computeNfiqMetrics": computeNfiqMetrics.toString(),
      "targetPixelsPerInch": (targetPixelsPerInch).toString(),
      "subjectId": (subjectId ?? ""),
      "uploadMetrics": uploadMetrics.toString(),
      "returnOnyxErrorOnLowQuality": returnOnyxErrorOnLowQuality.toString(),
      "captureQualityThreshold": captureQualityThreshold.toString(),
    };
  }
}
